lib

package
v0.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 6, 2026 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package lib provides library functions for abaper that can be imported by other Go programs This package serves as a thin wrapper around the internal/adt package

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func CreateADTClient

func CreateADTClient(host, client, username, password string) (types.ADTClient, error)

CreateADTClient creates an ADT client from simplified parameters This provides a higher-level interface that's easier to use from other packages

func NewADTClient

func NewADTClient(config *types.ADTConfig) types.ADTClient

NewADTClient creates a new ADT client using the internal implementation This is the library version that external packages can import

Types

This section is empty.

Jump to