Documentation
¶
Overview ¶
Package lib provides library functions for abaper that can be imported by other Go programs This package serves as a thin wrapper around the internal/adt package
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func CreateADTClient ¶
CreateADTClient creates an ADT client from simplified parameters This provides a higher-level interface that's easier to use from other packages
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.